@@ -503,10 +503,10 @@ int config_file_read_fd(struct dm_config_tree *cft, struct device *dev, dev_io_r
 {
 	char *fb, *fe;
 	int r = 0;
-	int use_mmap = 1;
-	off_t mmap_offset = 0;
+	int sz, use_plain_read = 1;
 	char *buf = NULL;
 	struct config_source *cs = dm_config_get_custom(cft);
+	size_t rsize;
 
 	if (!_is_file_based_config_source(cs->type)) {
 		log_error(INTERNAL_ERROR "config_file_read_fd: expected file, special file "
@@ -515,26 +515,28 @@ int config_file_read_fd(struct dm_config_tree *cft, struct device *dev, dev_io_r
 		return 0;
 	}
 
-	/* Only use mmap with regular files */
+	/* Only use plain read with regular files */
 	if (!(dev->flags & DEV_REGULAR) || size2)
-		use_mmap = 0;
+		use_plain_read = 0;
 
-	if (use_mmap) {
-		mmap_offset = offset % lvm_getpagesize();
-		/* memory map the file */
-		fb = mmap((caddr_t) 0, size + mmap_offset, PROT_READ,
-			  MAP_PRIVATE, dev_fd(dev), offset - mmap_offset);
-		if (fb == (caddr_t) (-1)) {
-			log_sys_error("mmap", dev_name(dev));
-			goto out;
+	if (!(buf = malloc(size + size2))) {
+		log_error("Failed to allocate circular buffer.");
+		return 0;
+	}
+
+	if (use_plain_read) {
+		/* Note: also used for lvm.conf to read all settings */
+		for (rsize = 0; rsize < size; rsize += sz) {
+			do {
+				sz = read(dev_fd(dev), buf + rsize, size - rsize);
+			} while ((sz < 0) && ((errno == EINTR) || (errno == EAGAIN)));
+
+			if (sz < 0) {
+				log_sys_error("read", dev_name(dev));
+				goto out;
+			}
 		}
-		fb = fb + mmap_offset;
 	} else {
-		if (!(buf = malloc(size + size2))) {
-			log_error("Failed to allocate circular buffer.");
-			return 0;
-		}
-
 		if (!dev_read_bytes(dev, offset, size, buf))
 			goto out;
 
@@ -542,10 +544,10 @@ int config_file_read_fd(struct dm_config_tree *cft, struct device *dev, dev_io_r
 			if (!dev_read_bytes(dev, offset2, size2, buf + size))
 				goto out;
 		}
-
-		fb = buf;
 	}
 
+	fb = buf;
+
 	/*
 	 * The checksum passed in is the checksum from the mda_header
 	 * preceding this metadata.  They should always match.
@@ -573,15 +575,7 @@ int config_file_read_fd(struct dm_config_tree *cft, struct device *dev, dev_io_r
 	r = 1;
 
       out:
-	if (!use_mmap)
-		free(buf);
-	else {
-		/* unmap the file */
-		if (munmap(fb - mmap_offset, size + mmap_offset)) {
-			log_sys_error("munmap", dev_name(dev));
-			r = 0;
-		}
-	}
+	free(buf);
 
 	return r;
 }
@@ -716,7 +710,7 @@ static struct dm_config_value *_get_def_array_values(struct cmd_context *cmd,
 		return array;
 	}
 
-	if (!(p = token = enc_value = strdup(def_enc_value))) {
+	if (!(token = enc_value = strdup(def_enc_value))) {
 		log_error("_get_def_array_values: strdup failed");
 		return NULL;
 	}
@@ -1147,8 +1141,10 @@ int config_def_check(struct cft_check_handle *handle)
 	 * sections and settings with full path as a key.
 	 * If section name is variable, use '#' as a substitute.
 	 */
+	*vp = 0;
+	*rp = 0;
 	if (!handle->cmd->cft_def_hash) {
-		if (!(handle->cmd->cft_def_hash = dm_hash_create(64))) {
+		if (!(handle->cmd->cft_def_hash = dm_hash_create(60))) {
 			log_error("Failed to create configuration definition hash.");
 			r = 0; goto out;
 		}
@@ -1714,6 +1710,7 @@ static int _out_prefix_fn(const struct dm_config_node *cn, const char *line, voi
 	const char *node_type_name = cn->v ? "option" : "section";
 	char path[CFG_PATH_MAX_LEN];
 	char commentline[MAX_COMMENT_LINE+1];
+	int is_deprecated = 0;
 
 	if (cn->id <= 0)
 		return 1;
@@ -1727,13 +1724,14 @@ static int _out_prefix_fn(const struct dm_config_node *cn, const char *line, voi
 
 	cfg_def = cfg_def_get_item_p(cn->id);
 
+	is_deprecated = _def_node_is_deprecated(cfg_def, out->tree_spec);
+
 	if (out->tree_spec->withsummary || out->tree_spec->withcomments) {
 		_cfg_def_make_path(path, sizeof(path), cfg_def->id, cfg_def, 1);
 		fprintf(out->fp, "\n");
 		fprintf(out->fp, "%s# Configuration %s %s.\n", line, node_type_name, path);
 
-		if (out->tree_spec->withcomments &&
-		    _def_node_is_deprecated(cfg_def, out->tree_spec))
+		if (out->tree_spec->withcomments && is_deprecated && cfg_def->deprecation_comment)
 			fprintf(out->fp, "%s# %s", line, cfg_def->deprecation_comment);
 
 		if (cfg_def->comment) {
@@ -1744,14 +1742,14 @@ static int _out_prefix_fn(const struct dm_config_node *cn, const char *line, voi
 						continue;
 					commentline[0] = '\0';
 				}
-				fprintf(out->fp, "%s# %s\n", line, commentline);
+				fprintf(out->fp, "%s#%s%s\n", line, commentline[0] ? " " : "", commentline);
 				/* withsummary prints only the first comment line. */
 				if (!out->tree_spec->withcomments)
 					break;
 			}
 		}
 
-		if (_def_node_is_deprecated(cfg_def, out->tree_spec))
+		if (is_deprecated)
 			fprintf(out->fp, "%s# This configuration %s is deprecated.\n", line, node_type_name);
 
 		if (cfg_def->flags & CFG_ADVANCED)
@@ -1779,7 +1777,7 @@ static int _out_prefix_fn(const struct dm_config_node *cn, const char *line, voi
 			return_0;
 		fprintf(out->fp, "%s# Available since version %s.\n", line, version);
 
-		if (_def_node_is_deprecated(cfg_def, out->tree_spec)) {
+		if (is_deprecated) {
 			if (!_get_config_node_version(cfg_def->deprecated_since_version, version))
 				return_0;
 			fprintf(out->fp, "%s# Deprecated since version %s.\n", line, version);
