@@ -37,20 +37,29 @@ arg(activationmode_ARG, '\0', "activationmode", activationmode_VAL, 0, 0,
     "(This does not include the \"mirror\" type, see \"raid1\" instead.)\n"
     "\\fBpartial\\fP allows any LV with missing PVs to be activated, and\n"
     "should only be used for recovery or repair.\n"
-    "For default, see lvm.conf/activation_mode.\n"
+    "For default, see \\fBlvm.conf\\fP(5) activation_mode.\n"
     "See \\fBlvmraid\\fP(7) for more information.\n")
 
 arg(addtag_ARG, '\0', "addtag", tag_VAL, ARG_GROUPABLE, 0,
     "Adds a tag to a PV, VG or LV. This option can be repeated to add\n"
     "multiple tags at once. See \\fBlvm\\fP(8) for information about tags.\n")
 
+arg(adddev_ARG, '\0', "adddev", pv_VAL, 0, 0,
+    "Add a device to the devices file.\n")
+arg(deldev_ARG, '\0', "deldev", pv_VAL, 0, 0,
+    "Remove a device from the devices file.\n")
+arg(addpvid_ARG, '\0', "addpvid", string_VAL, 0, 0,
+    "Find a device with the PVID and add the device to the devices file.\n")
+arg(delpvid_ARG, '\0', "delpvid", string_VAL, 0, 0,
+    "Remove a device with the PVID from the devices file.\n")
+
 arg(aligned_ARG, '\0', "aligned", 0, 0, 0,
     "Use with --separator to align the output columns\n")
 
 arg(alloc_ARG, '\0', "alloc", alloc_VAL, 0, 0,
     "Determines the allocation policy when a command needs to allocate\n"
     "Physical Extents (PEs) from the VG. Each VG and LV has an allocation policy\n"
-    "which can be changed with vgchange/lvchange, or overriden on the\n"
+    "which can be changed with vgchange/lvchange, or overridden on the\n"
     "command line.\n"
     "\\fBnormal\\fP applies common sense rules such as not placing parallel stripes\n"
     "on the same PV.\n"
@@ -78,6 +87,17 @@ arg(atversion_ARG, '\0', "atversion", string_VAL, 0, 0,
     "which does not contain any newer settings for which LVM would\n"
     "issue a warning message when checking the configuration.\n")
 
+arg(setautoactivation_ARG, '\0', "setautoactivation", bool_VAL, 0, 0,
+    "Set the autoactivation property on a VG or LV.\n"
+    "Display the property with vgs or lvs \"-o autoactivation\".\n"
+    "When the autoactivation property is disabled, the VG or LV\n"
+    "will not be activated by a command doing autoactivation\n"
+    "(vgchange, lvchange, or pvscan using -aay.)\n"
+    "If autoactivation is disabled on a VG, no LVs will be autoactivated\n"
+    "in that VG, and the LV autoactivation property has no effect.\n"
+    "If autoactivation is enabled on a VG, autoactivation can be disabled\n"
+    "for individual LVs.\n")
+
 arg(binary_ARG, '\0', "binary", 0, 0, 0,
     "Use binary values \"0\" or \"1\" instead of descriptive literal values\n"
     "for columns that have exactly two valid values to report (not counting\n"
@@ -126,6 +146,15 @@ arg(cachepool_ARG, '\0', "cachepool", lv_VAL, 0, 0,
 arg(cachevol_ARG, '\0', "cachevol", lv_VAL, 0, 0,
     "The name of a cache volume.\n")
 
+arg(cachedevice_ARG, '\0', "cachedevice", pv_VAL, ARG_GROUPABLE, 0,
+    "The name of a device to use for a cache.\n")
+
+arg(cachesize_ARG, '\0', "cachesize", sizemb_VAL, 0, 0,
+    "The size of cache to use.\n")
+
+arg(check_ARG, '\0', "check", 0, 0, 0,
+    "Check the content of the devices file.\n")
+
 arg(commandprofile_ARG, '\0', "commandprofile", string_VAL, 0, 0,
     "The command profile to use for command configuration.\n"
     "See \\fBlvm.conf\\fP(5) for more information about profiles.\n")
@@ -135,8 +164,8 @@ arg(compression_ARG, '\0', "compression", bool_VAL, 0, 0,
     "See \\fBlvmvdo\\fP(7) for more information about VDO usage.\n")
 
 arg(config_ARG, '\0', "config", string_VAL, 0, 0,
-    "Config settings for the command. These override lvm.conf settings.\n"
-    "The String arg uses the same format as lvm.conf,\n"
+    "Config settings for the command. These override \\fBlvm.conf\\fP(5) settings.\n"
+    "The String arg uses the same format as \\fBlvm.conf\\fP(5),\n"
     "or may use section/field syntax.\n"
     "See \\fBlvm.conf\\fP(5) for more information about config.\n")
 
@@ -199,6 +228,18 @@ arg(detachprofile_ARG, '\0', "detachprofile", 0, 0, 0,
     "Detaches a metadata profile from a VG or LV.\n"
     "See \\fBlvm.conf\\fP(5) for more information about profiles.\n")
 
+arg(devices_ARG, '\0', "devices", pv_VAL, ARG_GROUPABLE, 0,
+    "Devices that the command can use. This option can be repeated\n"
+    "or accepts a comma separated list of devices. This overrides\n"
+    "the devices file.\n")
+
+arg(devicesfile_ARG, '\0', "devicesfile", string_VAL, 0, 0,
+    "A file listing devices that LVM should use.\n"
+    "The file must exist in \\fI#DEFAULT_SYS_DIR#/devices/\\fP and is managed\n"
+    "with the \\fBlvmdevices\\fP(8) command.\n"
+    "This overrides the \\fBlvm.conf\\fP(5) \\fBdevices/devicesfile\\fP and\n"
+    "\\fBdevices/use_devicesfile\\fP settings.\n")
+
 arg(discards_ARG, '\0', "discards", discards_VAL, 0, 0,
     "Specifies how the device-mapper thin pool layer in the kernel should\n"
     "handle discards.\n"
@@ -213,12 +254,14 @@ arg(driverloaded_ARG, '\0', "driverloaded", bool_VAL, 0, 0,
     "If set to no, the command will not attempt to use device-mapper.\n"
     "For testing and debugging.\n")
 
-arg(dump_ARG, '\0', "dump", string_VAL, 0, 0,
-    "Dump metadata from a PV. Option values include \\fBmetadata\\fP\n"
-    "to print or save the current text metadata, \\fBmetadata_area\\fP\n"
-    "to save the entire text metadata area to a file, \\fBmetadata_all\\fP\n"
-    "to save the current and any previous complete versions of metadata\n"
-    "to a file, and \\fBheaders\\fP to print and check LVM headers.\n")
+arg(dump_ARG, '\0', "dump", dumptype_VAL, 0, 0,
+    "Dump headers and metadata from a PV for debugging and repair.\n"
+    "Option values include: \\fBheaders\\fP to print and check LVM headers,\n"
+    "\\fBmetadata\\fP to print or save the current text metadata,\n"
+    "\\fBmetadata_all\\fP to list or save all versions of metadata,\n"
+    "\\fBmetadata_search\\fP to list or save all versions of metadata,\n"
+    "searching standard locations in case of damaged headers,\n"
+    "\\fBmetadata_area\\fP to save an entire text metadata area to a file.\n")
 
 arg(errorwhenfull_ARG, '\0', "errorwhenfull", bool_VAL, 0, 0,
     "Specifies thin pool behavior when data space is exhausted.\n"
@@ -272,6 +315,9 @@ arg(ignoreunsupported_ARG, '\0', "ignoreunsupported", 0, 0, 0,
     "and \\fBdiff\\fP types include unsupported settings in their output by default,\n"
     "all the other types ignore unsupported settings.\n")
 
+arg(importdevices_ARG, '\0', "importdevices", 0, 0, 0,
+    "Add devices to the devices file.\n")
+
 arg(labelsector_ARG, '\0', "labelsector", number_VAL, 0, 0,
     "By default the PV is labelled with an LVM2 identifier in its second\n"
     "sector (sector 1). This lets you use a different sector near the\n"
@@ -459,6 +505,11 @@ arg(setphysicalvolumesize_ARG, '\0', "setphysicalvolumesize", sizemb_VAL, 0, 0,
     "Overrides the automatically detected size of the PV.\n"
     "Use with care, or prior to reducing the physical size of the device.\n")
 
+arg(settings_ARG, '\0', "settings", string_VAL, ARG_GROUPABLE, 0,
+    "Specifies command specific settings in \"Key = Value\" form.\n"
+    "Combine multiple settings in quotes, or repeat the settings\n"
+    "option for each.\n")
+
 arg(poll_ARG, '\0', "poll", bool_VAL, 0, 0,
     "When yes, start the background transformation of an LV.\n"
     "An incomplete transformation, e.g. pvmove or lvconvert interrupted\n"
@@ -505,6 +556,26 @@ arg(pvmetadatacopies_ARG, '\0', "pvmetadatacopies", pvmetadatacopies_VAL, 0, 0,
     "This may be useful in VGs containing many PVs (this places limitations\n"
     "on the ability to use vgsplit later.)\n")
 
+arg(raidintegrity_ARG, '\0', "raidintegrity", bool_VAL, 0, 0,
+    "Enable or disable data integrity checksums for raid images.\n")
+
+arg(raidintegrityblocksize_ARG, '\0', "raidintegrityblocksize", number_VAL, 0, 0,
+    "The block size to use for dm-integrity on raid images.\n"
+    "The integrity block size should usually match the device\n"
+    "logical block size, or the file system block size.\n"
+    "It may be less than the file system block size, but not\n"
+    "less than the device logical block size.\n"
+    "Possible values: 512, 1024, 2048, 4096.\n")
+
+arg(raidintegritymode_ARG, '\0', "raidintegritymode", string_VAL, 0, 0,
+    "Use a journal (default) or bitmap for keeping integrity checksums consistent\n"
+    "in case of a crash. The bitmap areas are recalculated after a crash, so corruption\n"
+    "in those areas would not be detected. A journal does not have this problem.\n"
+    "The journal mode doubles writes to storage, but can improve performance for\n"
+    "scattered writes packed into a single journal write.\n"
+    "bitmap mode can in theory achieve full write throughput of the device,\n"
+    "but would not benefit from the potential scattered write optimization.\n")
+
 arg(readonly_ARG, '\0', "readonly", 0, 0, 0,
     "Run the command in a special read-only mode which will read on-disk\n"
     "metadata without needing to take any locks. This can be used to peek\n"
@@ -540,9 +611,15 @@ arg(rebuild_ARG, '\0', "rebuild", pv_VAL, ARG_GROUPABLE, 0,
     "See \\fBlvmraid\\fP(7) for more information.\n")
 
 arg(repair_ARG, '\0', "repair", 0, 0, 0,
+    "#lvconvert\n"
     "Replace failed PVs in a raid or mirror LV, or run a repair\n"
     "utility on a thin pool. See \\fBlvmraid\\fP(7) and \\fBlvmthin\\fP(7)\n"
-    "for more information.\n")
+    "for more information.\n"
+    "#pvck\n"
+    "Repair headers and metadata on a PV.\n")
+
+arg(repairtype_ARG, '\0', "repairtype", repairtype_VAL, 0, 0,
+    "Repair headers and metadata on a PV. See command description.\n")
 
 arg(replace_ARG, '\0', "replace", pv_VAL, ARG_GROUPABLE, 0,
     "Replace a specific PV in a raid LV with another PV.\n"
@@ -552,7 +629,7 @@ arg(replace_ARG, '\0', "replace", pv_VAL, ARG_GROUPABLE, 0,
 
 arg(reportformat_ARG, '\0', "reportformat", reportformat_VAL, 0, 0,
     "Overrides current output format for reports which is defined globally by\n"
-    "the report/output_format setting in lvm.conf.\n"
+    "the report/output_format setting in \\fBlvm.conf\\fP(5).\n"
     "\\fBbasic\\fP is the original format with columns and rows.\n"
     "If there is more than one report per command, each report is prefixed\n"
     "with the report name for identification. \\fBjson\\fP produces report\n"
@@ -674,7 +751,7 @@ arg(syncaction_ARG, '\0', "syncaction", syncaction_VAL, 0, 0,
     "(mismatches between mirrors or incorrect parity values).\n"
     "\\fBcheck\\fP will count but not correct discrepancies.\n"
     "\\fBrepair\\fP will correct discrepancies.\n"
-    "See lvs for reporting discrepancies found or repaired.\n")
+    "See \\fBlvs\\fP(8) for reporting discrepancies found or repaired.\n")
     
 arg(sysinit_ARG, '\0', "sysinit", 0, 0, 0,
     "Indicates that vgchange/lvchange is being invoked from early system initialisation\n"
@@ -713,9 +790,8 @@ arg(trackchanges_ARG, '\0', "trackchanges", 0, 0, 0,
     "merging the split image (see --mergemirrors) or permanently splitting\n"
     "the image (see --splitmirrors with --name.\n")
 
-/* TODO: hide this? */
 arg(trustcache_ARG, '\0', "trustcache", 0, 0, 0,
-    "Avoids certain device scanning during command processing. Do not use.\n")
+    "No longer used.\n")
 
 arg(type_ARG, '\0', "type", segtype_VAL, 0, 0,
     "The LV type, also known as \"segment type\" or \"segtype\".\n"
@@ -737,6 +813,9 @@ arg(uncache_ARG, '\0', "uncache", 0, 0, 0,
     "Separates a cache pool from a cache LV, and deletes the unused cache pool LV.\n"
     "Before the separation, the cache is flushed. Also see --splitcache.\n")
 
+arg(update_ARG, '\0', "update", 0, 0, 0,
+    "Update the content of the devices file.\n")
+
 arg(cachepolicy_ARG, '\0', "cachepolicy", string_VAL, 0, 0,
     "Specifies the cache policy for a cache LV.\n"
     "See \\fBlvmcache\\fP(7) for more information.\n")
@@ -766,7 +845,7 @@ arg(unquoted_ARG, '\0', "unquoted", 0, 0, 0,
     "pairs are not quoted.\n")
 
 arg(usepolicies_ARG, '\0', "usepolicies", 0, 0, 0,
-    "Perform an operation according to the policy configured in lvm.conf\n"
+    "Perform an operation according to the policy configured in \\fBlvm.conf\\fP(5)\n"
     "or a profile.\n")
 
 arg(validate_ARG, '\0', "validate", 0, 0, 0,
@@ -774,7 +853,7 @@ arg(validate_ARG, '\0', "validate", 0, 0, 0,
     "return code. The validation is done only for the configuration\n"
     "at the front of the \"config cascade\". To validate the whole\n"
     "merged configuration tree, also use --mergedconfig.\n"
-    "The validation is done even if lvm.conf config/checks is disabled.\n")
+    "The validation is done even if \\fBlvm.conf\\fP(5) \\fBconfig/checks\\fP is disabled.\n")
 
 arg(vdo_ARG, '\0', "vdo", 0, 0, 0,
     "Specifies the command is handling VDO LV.\n"
@@ -892,12 +971,17 @@ arg(activate_ARG, 'a', "activate", activation_VAL, 0, 0,
     "link and present this as the name of the device.\n"
     "The location and name of the underlying device node may depend on\n"
     "the distribution, configuration (e.g. udev), or release version.\n"
-    "\\fBay\\fP specifies autoactivation, in which case an LV is activated\n"
-    "only if it matches an item in lvm.conf activation/auto_activation_volume_list.\n"
-    "If the list is not set, all LVs are considered to match, and if\n"
-    "if the list is set but empty, no LVs match.\n"
-    "Autoactivation should be used during system boot to make it possible\n"
-    "to select which LVs should be automatically activated by the system.\n"
+    "\\fBay\\fP specifies autoactivation, which is used by system-generated\n"
+    "activation commands.  By default, LVs are autoactivated.\n"
+    "An autoactivation property can be set on a VG or LV to disable autoactivation,\n"
+    "see --setautoactivation y|n in vgchange, lvchange, vgcreate, and lvcreate.\n"
+    "Display the property with vgs or lvs \"-o autoactivation\".\n"
+    "The \\fBlvm.conf\\fP(5) auto_activation_volume_list includes names of VGs or LVs\n"
+    "that should be autoactivated, and anything not listed is not autoactivated.\n"
+    "When auto_activation_volume_list is undefined (the default), it has no effect.\n"
+    "If auto_activation_volume_list is defined and empty, no LVs are autoactivated.\n"
+    "Items included by auto_activation_volume_list will not be autoactivated if\n"
+    "the autoactivation property has been disabled.\n"
     "See \\fBlvmlockd\\fP(8) for more information about activation options \\fBey\\fP and \\fBsy\\fP for shared VGs.\n"
     "#lvcreate\n"
     "Controls the active state of the new LV.\n"
@@ -909,7 +993,7 @@ arg(activate_ARG, 'a', "activate", activation_VAL, 0, 0,
     "be created in the active state (this does not apply to thin snapshots).\n"
     "The --zero option normally requires the LV to be active.\n"
     "If autoactivation \\fBay\\fP is used, the LV is only activated\n"
-    "if it matches an item in lvm.conf activation/auto_activation_volume_list.\n"
+    "if it matches an item in \\fBlvm.conf\\fP(5) \\fBactivation/auto_activation_volume_list\\fP.\n"
     "\\fBay\\fP implies --zero n and --wipesignatures n.\n"
     "See \\fBlvmlockd\\fP(8) for more information about activation options for shared VGs.\n")
 
@@ -998,6 +1082,8 @@ arg(exported_ARG, 'e', "exported", 0, 0, 0,
 arg(physicalextent_ARG, 'E', "physicalextent", 0, 0, 0, NULL)
 
 arg(file_ARG, 'f', "file", string_VAL, 0, 0,
+    "#pvck\n"
+    "Metadata file to read or write.\n"
     "#lvmconfig\n"
     "#dumpconfig\n"
     "#config\n"
@@ -1028,7 +1114,7 @@ arg(cache_ARG, 'H', "cache", 0, 0, 0,
 arg(history_ARG, 'H', "history", 0, 0, 0,
     "Include historical LVs in the output.\n"
     "(This has no effect unless LVs were removed while\n"
-    "lvm.conf metadata/record_lvs_history was enabled.\n")
+    "\\fBlvm.conf\\fP(5) \\fBmetadata/record_lvs_history\\fP was enabled.\n")
 
 /* Not used */
 arg(help2_ARG, '?', "", 0, 0, 0, NULL)
@@ -1055,7 +1141,7 @@ arg(stripes_ARG, 'i', "stripes", number_VAL, 0, 0,
     "when unspecified, the default depends on the RAID type\n"
     "(raid0: 2, raid10: 2, raid4/5: 3, raid6: 5.)\n"
     "To stripe a new raid LV across all PVs by default,\n"
-    "see lvm.conf allocation/raid_stripe_all_devices.\n")
+    "see \\fBlvm.conf\\fP(5) \\fBallocation/raid_stripe_all_devices\\fP.\n")
 
 arg(stripesize_ARG, 'I', "stripesize", sizekb_VAL, 0, 0,
     "The amount of data that is written to one device before\n"
@@ -1068,7 +1154,7 @@ arg(maxlogicalvolumes_ARG, 'l', "maxlogicalvolumes", uint32_VAL, 0, 0,
     "Sets the maximum number of LVs allowed in a VG.\n")
 
 /*
- * The extents_VAL is overriden in configure_command_option_values()
+ * The extents_VAL is overridden in configure_command_option_values()
  * according to the command being run.  Different commands accept
  * different signs with the value.
  */
@@ -1127,7 +1213,7 @@ arg(lvmpartition_ARG, 'l', "lvmpartition", 0, 0, 0,
     "Only report PVs.\n")
 
 /*
- * The sizemb_VAL is overriden in configure_command_option_values()
+ * The sizemb_VAL is overridden in configure_command_option_values()
  * according to the command being run.  Different commands accept
  * different signs with the value.
  */
@@ -1191,7 +1277,7 @@ arg(mirrors_ARG, 'm', "mirrors", number_VAL, 0, 0,
     "These are the names of the corresponding LV types, or \"segment types\".\n"
     "Use the --type option to specify which to use (raid1 is default,\n"
     "and mirror is legacy)\n"
-    "Use lvm.conf global/mirror_segtype_default and\n"
+    "Use \\fBlvm.conf\\fP(5) \\fBglobal/mirror_segtype_default\\fP and\n"
     "global/raid10_segtype_default to configure the default types.\n"
     "See the --nosync option for avoiding initial image synchronization.\n"
     "See \\fBlvmraid\\fP(7) for more information.\n"
@@ -1205,7 +1291,7 @@ arg(mirrors_ARG, 'm', "mirrors", number_VAL, 0, 0,
     "These are the names of the corresponding LV types, or \"segment types\".\n"
     "Use the --type option to specify which to use (raid1 is default,\n"
     "and mirror is legacy)\n"
-    "Use lvm.conf global/mirror_segtype_default and\n"
+    "Use \\fBlvm.conf\\fP(5) \\fBglobal/mirror_segtype_default\\fP and\n"
     "global/raid10_segtype_default to configure the default types.\n"
     "The plus prefix \\fB+\\fP can be used, in which case\n"
     "the number is added to the current number of images,\n"
@@ -1250,7 +1336,7 @@ arg(oldpath_ARG, 'n', "oldpath", 0, 0, 0, NULL)
 
 arg(options_ARG, 'o', "options", string_VAL, ARG_GROUPABLE, 0,
     "Comma-separated, ordered list of fields to display in columns.\n"
-    "String arg syntax is: [+|-|#]Field1[,Field2 ...]\n"
+    "String arg syntax is: [\\fB+\\fP|\\fB-\\fP|\\fB#\\fP]\\fIField1\\fP[\\fB,\\fP\\fIField2\\fP ...]\n"
     "The prefix \\fB+\\fP will append the specified fields to the default fields,\n"
     "\\fB-\\fP will remove the specified fields from the default fields, and\n"
     "\\fB#\\fP will compact specified fields (removing them when empty for all rows.)\n"
@@ -1264,7 +1350,7 @@ arg(options_ARG, 'o', "options", string_VAL, ARG_GROUPABLE, 0,
     "\\fBpvseg_all\\fP all PV segment fields,\n"
     "\\fBseg_all\\fP all LV segment fields, and\n"
     "\\fBpvseg_all\\fP all PV segment columns.\n"
-    "See the lvm.conf report section for more config options.\n"
+    "See the \\fBlvm.conf\\fP(5) report section for more config options.\n"
     "See \\fBlvmreport\\fP(7) for more information about reporting.\n")
 
 arg(sort_ARG, 'O', "sort", string_VAL, ARG_GROUPABLE, 0,
@@ -1283,7 +1369,7 @@ arg(permission_ARG, 'p', "permission", permission_VAL, 0, 0,
 arg(partial_ARG, 'P', "partial", 0, 0, 0,
     "Commands will do their best to activate LVs with missing PV extents.\n"
     "Missing extents may be replaced with error or zero segments\n"
-    "according to the lvm.conf missing_stripe_filler setting.\n"
+    "according to the  missing_stripe_filler setting.\n"
     "Metadata may not be changed with this option.\n")
 
 /* Not used */
@@ -1300,14 +1386,14 @@ arg(readahead_ARG, 'r', "readahead", readahead_VAL, 0, 0,
     "\\fBnone\\fP is equivalent to zero.\n")
 
 arg(resizefs_ARG, 'r', "resizefs", 0, 0, 0,
-    "Resize underlying filesystem together with the LV using fsadm(8).\n")
+    "Resize underlying filesystem together with the LV using \\fBfsadm\\fP(8).\n")
 
 /* Not used */
 arg(reset_ARG, 'R', "reset", 0, 0, 0, NULL)
 
 arg(regionsize_ARG, 'R', "regionsize", regionsizemb_VAL, 0, 0,
     "Size of each raid or mirror synchronization region.\n"
-    "lvm.conf activation/raid_region_size can be used to\n"
+    "\\fBlvm.conf\\fP(5) \\fBactivation/raid_region_size\\fP can be used to\n"
     "configure a default.\n")
 
 arg(physicalextentsize_ARG, 's', "physicalextentsize", sizemb_VAL, 0, 0,
@@ -1393,6 +1479,18 @@ arg(thin_ARG, 'T', "thin", 0, 0, 0,
     "See --type thin, --type thin-pool, and --virtualsize.\n"
     "See \\fBlvmthin\\fP(7) for more information about LVM thin provisioning.\n")
 
+arg(updatemetadata_ARG, '\0', "updatemetadata", 0, 0, 0,
+    "Update VG metadata to correct problems.\n"
+    "If VG metadata was updated while a PV was missing, and the PV\n"
+    "reappears with an old version of metadata, then this option\n"
+    "(or any other command that writes metadata) will update the\n"
+    "metadata on the previously missing PV. If a PV was removed\n"
+    "from a VG while it was missing, and the PV reappears, using\n"
+    "this option will clear the outdated metadata from the previously\n"
+    "missing PV. If metadata text is damaged on one PV, using this\n"
+    "option will replace the damaged metadata text. For more severe\n"
+    "damage, e.g. with headers, see \\fBpvck\\fP(8).\n")
+
 arg(uuid_ARG, 'u', "uuid", 0, 0, 0,
     "#pvchange\n"
     "Generate new random UUID for specified PVs.\n"
@@ -1426,7 +1524,7 @@ arg(virtualsize_ARG, 'V', "virtualsize", sizemb_VAL, 0, 0,
     "See \\fBlvmthin\\fP(7) for more information about LVM thin provisioning.\n"
     "Using virtual size (-V) and actual size (-L) together creates\n"
     "a sparse LV.\n"
-    "lvm.conf global/sparse_segtype_default determines the\n"
+    "\\fBlvm.conf\\fP(5) \\fBglobal/sparse_segtype_default\\fP determines the\n"
     "default segment type used to create a sparse LV.\n"
     "Anything written to a sparse LV will be returned when reading from it.\n"
     "Reading from other areas of the LV will return blocks of zeros.\n"
@@ -1441,8 +1539,8 @@ arg(wipesignatures_ARG, 'W', "wipesignatures", bool_VAL, 0, 0,
     "(unless --yes is used to override confirmations.)\n"
     "When not specified, signatures are wiped whenever zeroing is done\n"
     "(see --zero). This behaviour can be configured with\n"
-    "lvm.conf allocation/wipe_signatures_when_zeroing_new_lvs.\n"
-    "If blkid wiping is used (lvm.conf allocation/use_blkid_wiping)\n"
+    "\\fBlvm.conf\\fP(5) \\fBallocation/wipe_signatures_when_zeroing_new_lvs\\fP.\n"
+    "If blkid wiping is used (\\fBlvm.conf\\fP(5) \\fBallocation/use_blkid_wiping\\fP)\n"
     "and LVM is compiled with blkid wiping support, then the blkid(8)\n"
     "library is used to detect the signatures (use blkid -k to list the\n"
     "signatures that are recognized).\n"
