@@ -202,7 +202,7 @@ static int _lvchange_activate(struct cmd_context *cmd, struct logical_volume *lv
 	    strcmp(lv->vg->system_id, cmd->system_id) &&
 	    is_change_activating(activate)) {
 		log_error("Cannot activate LVs in a foreign VG.");
-		return ECMD_FAILED;
+		return 0;
 	}
 
 	if (lv_activation_skip(lv, activate, arg_is_set(cmd, ignoreactivationskip_ARG)))
@@ -215,6 +215,10 @@ static int _lvchange_activate(struct cmd_context *cmd, struct logical_volume *lv
 	    !lv_passes_auto_activation_filter(cmd, lv))
 		return 1;
 
+	if ((activate == CHANGE_AAY) &&
+	    ((lv->status & LV_NOAUTOACTIVATE) || (lv->vg->status & NOAUTOACTIVATE)))
+		return 1;
+
 	if (!lv_change_activate(cmd, lv, activate))
 		return_0;
 
@@ -410,13 +414,6 @@ static int _lvchange_resync(struct cmd_context *cmd, struct logical_volume *lv)
 	if (!activate_and_wipe_lvlist(&device_list, 0))
 		return 0;
 
-	/* Wait until devices are away */
-	if (!sync_local_dev_names(lv->vg->cmd)) {
-		log_error("Failed to sync local devices after updating %s.",
-			  display_lvname(lv));
-		return 0;
-	}
-
 	/* Put metadata sub-LVs back in place */
 	if (!_attach_metadata_devices(seg, &device_list)) {
 		log_error("Failed to reattach %s device after clearing.",
@@ -1016,6 +1013,28 @@ static int _lvchange_activation_skip(struct logical_volume *lv, uint32_t *mr)
 	return 1;
 }
 
+static int _lvchange_autoactivation(struct logical_volume *lv, uint32_t *mr)
+{
+	int aa_no_arg = !arg_int_value(lv->vg->cmd, setautoactivation_ARG, 0);
+	int aa_no_meta = (lv->status & LV_NOAUTOACTIVATE);
+
+	if ((aa_no_arg && aa_no_meta) || (!aa_no_arg && !aa_no_meta))
+		return 1;
+
+	if (aa_no_arg)
+		lv->status |= LV_NOAUTOACTIVATE;
+	else
+		lv->status &= ~LV_NOAUTOACTIVATE;
+
+	log_verbose("Changing autoactivation flag to %s for LV %s.",
+		    display_lvname(lv), aa_no_arg ? "no" : "yes");
+
+	/* Request caller to commit+backup metadata */
+	*mr |= MR_COMMIT;
+
+	return 1;
+}
+
 static int _lvchange_compression(struct logical_volume *lv, uint32_t *mr)
 {
 	struct cmd_context *cmd = lv->vg->cmd;
@@ -1119,6 +1138,7 @@ static int _option_allows_group_commit(int opt_enum)
 		metadataprofile_ARG,
 		detachprofile_ARG,
 		setactivationskip_ARG,
+		setautoactivation_ARG,
 		-1
 	};
 
@@ -1257,6 +1277,11 @@ static int _lvchange_properties_single(struct cmd_context *cmd,
 			doit += _lvchange_activation_skip(lv, &mr);
 			break;
 
+		case setautoactivation_ARG:
+			docmds++;
+			doit += _lvchange_autoactivation(lv, &mr);
+			break;
+
 		case compression_ARG:
 			docmds++;
 			doit += _lvchange_compression(lv, &mr);
@@ -1658,16 +1683,18 @@ static int _lvchange_syncaction_single(struct cmd_context *cmd,
 				       struct logical_volume *lv,
 				       struct processing_handle *handle)
 {
-	if (lv_raid_has_integrity(lv)) {
-		log_error("Integrity must be removed to use syncaction commands.");
-		return_ECMD_FAILED;
+	const char *msg = arg_str_value(cmd, syncaction_ARG, NULL);
+
+	if (lv_raid_has_integrity(lv) && !strcmp(msg, "repair")) {
+		log_error("Use syncaction check to detect and correct integrity checksum mismatches.");
+		return ECMD_FAILED;
 	}
 
 	/* If LV is inactive here, ensure it's not active elsewhere. */
 	if (!lockd_lv(cmd, lv, "ex", 0))
 		return_ECMD_FAILED;
 
-	if (!lv_raid_message(lv, arg_str_value(cmd, syncaction_ARG, NULL)))
+	if (!lv_raid_message(lv, msg))
 		return_ECMD_FAILED;
 
 	return ECMD_PROCESSED;
