@@ -391,6 +391,8 @@ static int _update_extents_params(struct volume_group *vg,
 						     lp->segtype, lp->target_attr,
 						     lp->extents,
 						     &lp->pool_metadata_extents,
+						     NULL,
+						     &lp->crop_metadata,
 						     &lp->thin_chunk_size_calc_policy,
 						     &lp->chunk_size,
 						     &lp->discards,
@@ -401,6 +403,7 @@ static int _update_extents_params(struct volume_group *vg,
 						      lp->segtype, lp->target_attr,
 						      lp->extents,
 						      &lp->pool_metadata_extents,
+						      NULL,
 						      &lp->thin_chunk_size_calc_policy,
 						      &lp->chunk_size))
 				return_0;
@@ -739,6 +742,9 @@ static int _read_activation_params(struct cmd_context *cmd,
 	if (arg_is_set(cmd, ignoreactivationskip_ARG))
 		lp->activation_skip |= ACTIVATION_SKIP_IGNORE;
 
+	if (arg_is_set(cmd, setautoactivation_ARG) && !arg_int_value(cmd, setautoactivation_ARG, 1))
+		lp->noautoactivate = 1;
+
 	return 1;
 }
 
@@ -1826,7 +1832,7 @@ static int _lvcreate_and_attach_writecache_single(struct cmd_context *cmd,
 		log_error("Removing new LV after failing to add writecache.");
 		if (!deactivate_lv(cmd, lv))
 			log_error("Failed to deactivate new LV %s.", display_lvname(lv));
-		if (!lv_remove_with_dependencies(cmd, lv, 1, 0))
+		if (!lv_remove_with_dependencies(cmd, lv, DONT_PROMPT, 0))
 			log_error("Failed to remove new LV %s.", display_lvname(lv));
 		return ECMD_FAILED;
 	}
@@ -1900,7 +1906,7 @@ static int _lvcreate_and_attach_cache_single(struct cmd_context *cmd,
 		log_error("Removing new LV after failing to add cache.");
 		if (!deactivate_lv(cmd, lv))
 			log_error("Failed to deactivate new LV %s.", display_lvname(lv));
-		if (!lv_remove_with_dependencies(cmd, lv, 1, 0))
+		if (!lv_remove_with_dependencies(cmd, lv, DONT_PROMPT, 0))
 			log_error("Failed to remove new LV %s.", display_lvname(lv));
 		return ECMD_FAILED;
 	}
