@@ -29,6 +29,7 @@
 #include "lib/config/defaults.h"
 #include "lib/device/dev-cache.h"
 #include "lib/device/device.h"
+#include "lib/device/device_id.h"
 #include "lib/display/display.h"
 #include "errors.h"
 #include "lib/metadata/metadata-exported.h"
@@ -109,8 +110,8 @@ struct arg_values {
 
 struct arg_value_group_list {
         struct dm_list list;
-        struct arg_values arg_values[0];
 	uint32_t prio;
+	struct arg_values arg_values[];
 };
 
 #define PERMITTED_READ_ONLY 	0x00000002
@@ -212,8 +213,6 @@ unsigned grouped_arg_is_set(const struct arg_values *av, int a);
 const char *grouped_arg_str_value(const struct arg_values *av, int a, const char *def);
 int32_t grouped_arg_int_value(const struct arg_values *av, int a, const int32_t def); 
 
-int integrity_mode_set(const char *mode, struct integrity_settings *settings);
-
 const char *command_name(struct cmd_context *cmd);
 
 int pvmove_poll(struct cmd_context *cmd, const char *pv_name, const char *uuid,
